==> gorilla-notes-0.4.0-20200914.094953-4.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$players$YouTube.js <==
import "./cljs_env.js";
shadow$provide.module$node_modules$react_player$lib$players$YouTube=function(global,require,module,exports){function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===
Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:
{};i%2?ownKeys(Object(source),!0).forEach(function(key){_defineProperty(target,key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=
!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _createSuper(Derived){return function(){var Super=_getPrototypeOf(Derived);if(_isNativeReflectConstruct()){var NewTarget=_getPrototypeOf(this).constructor;Super=Reflect.construct(Super,arguments,
NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _isNativeReflectConstruct(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,
[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,
configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}function _arrayLikeToArray(arr,len){if(null==len||len>arr.length)len=arr.length;for(var i=0,arr2=Array(len);i<
len;i++)arr2[i]=arr[i];return arr2}function parsePlaylist(url){if(MATCH_PLAYLIST.test(url)){url=url.match(MATCH_PLAYLIST);var JSCompiler_temp=Array.isArray(url)?url:void 0;if(!JSCompiler_temp)if("undefined"!==typeof Symbol&&Symbol.iterator in Object(url)){JSCompiler_temp=[];var _n=!0,_d=!1,_e=void 0;try{var JSCompiler_temp$jscomp$0=url[Symbol.iterator]();for(var _s;!(_n=(_s=JSCompiler_temp$jscomp$0.next()).done)&&(JSCompiler_temp.push(_s.value),2!==JSCompiler_temp.length);_n=!0);}catch(err){_d=!0,
_e=err}finally{try{if(!_n&&null!=JSCompiler_temp$jscomp$0["return"])JSCompiler_temp$jscomp$0["return"]()}finally{if(_d)throw _e;}}}else JSCompiler_temp=void 0;if(!(JSCompiler_temp$jscomp$0=JSCompiler_temp))a:{if(url){if("string"===typeof url){JSCompiler_temp$jscomp$0=_arrayLikeToArray(url,2);break a}JSCompiler_temp$jscomp$0=Object.prototype.toString.call(url).slice(8,-1);"Object"===JSCompiler_temp$jscomp$0&&url.constructor&&(JSCompiler_temp$jscomp$0=url.constructor.name);if("Map"===JSCompiler_temp$jscomp$0||
"Set"===JSCompiler_temp$jscomp$0){JSCompiler_temp$jscomp$0=Array.from(JSCompiler_temp$jscomp$0);break a}if("Arguments"===JSCompiler_temp$jscomp$0||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(JSCompiler_temp$jscomp$0)){JSCompiler_temp$jscomp$0=_arrayLikeToArray(url,2);break a}}JSCompiler_temp$jscomp$0=void 0}if(!(url=JSCompiler_temp$jscomp$0))throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
return{listType:"playlist",list:url[1]}}return{}}Object.defineProperty(exports,"__esModule",{value:!0});exports["default"]=exports.YouTube=void 0;var _react=function(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{"default":obj};var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,
key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,key,desc):newObj[key]=obj[key]}newObj["default"]=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index")),_utils=require("module$node_modules$react_player$lib$utils");global=function(obj){return obj&&obj.__esModule?obj:{"default":obj}}(require("module$node_modules$react_player$lib$singlePlayer"));var MATCH_URL=/(?:youtu\.be\/|youtube\.com\/(?:embed\/|v\/|watch\?v=|watch\?.+&v=))((\w|-){11})|youtube\.com\/playlist\?list=/,
MATCH_PLAYLIST=/list=([a-zA-Z0-9_-]+)/;require=function(_Component){function YouTube(){if(!(this instanceof YouTube))throw new TypeError("Cannot call a class as a function");for(var _len=arguments.length,args=Array(_len),_key=0;_key<_len;_key++)args[_key]=arguments[_key];var _this=_super.call.apply(_super,[this].concat(args));_defineProperty(_assertThisInitialized(_this),"callPlayer",_utils.callPlayer);_defineProperty(_assertThisInitialized(_this),"onStateChange",function(_ref){_ref=_ref.data;var _this$props=
_this.props,onPlay=_this$props.onPlay,onPause=_this$props.onPause,onBuffer=_this$props.onBuffer,onBufferEnd=_this$props.onBufferEnd,onEnded=_this$props.onEnded,onReady=_this$props.onReady;_this$props=_this$props.loop;var _window$SDK_GLOBAL$Pl=window.YT.PlayerState,PAUSED=_window$SDK_GLOBAL$Pl.PAUSED,BUFFERING=_window$SDK_GLOBAL$Pl.BUFFERING,ENDED=_window$SDK_GLOBAL$Pl.ENDED,CUED=_window$SDK_GLOBAL$Pl.CUED;_ref===_window$SDK_GLOBAL$Pl.PLAYING&&(onPlay(),onBufferEnd());_ref===PAUSED&&onPause();_ref===
BUFFERING&&onBuffer();_ref===ENDED&&(onPlay=!!_this.callPlayer("getPlaylist"),_this$props&&!onPlay&&_this.play(),onEnded());_ref===CUED&&onReady()});_defineProperty(_assertThisInitialized(_this),"mute",function(){_this.callPlayer("mute")});_defineProperty(_assertThisInitialized(_this),"unmute",function(){_this.callPlayer("unMute")});_defineProperty(_assertThisInitialized(_this),"ref",function(container){_this.container=container});return _this}_inherits(YouTube,_Component);var _super=_createSuper(YouTube);
_createClass(YouTube,[{key:"load",value:function(url,isReady){var _this2=this,_this$props2=this.props,playing=_this$props2.playing,muted=_this$props2.muted,playsinline=_this$props2.playsinline,controls=_this$props2.controls,loop=_this$props2.loop,_onError=_this$props2.onError;_this$props2=_this$props2.config.youtube;var playerVars=_this$props2.playerVars,embedOptions=_this$props2.embedOptions,id=url&&url.match(MATCH_URL)[1];isReady?MATCH_PLAYLIST.test(url)?this.player.loadPlaylist(parsePlaylist(url)):
this.player.cueVideoById({videoId:id,startSeconds:(0,_utils.parseStartTime)(url)||playerVars.start,endSeconds:(0,_utils.parseEndTime)(url)||playerVars.end}):(0,_utils.getSDK)("https://www.youtube.com/iframe_api","YT","onYouTubeIframeAPIReady",function(YT){return YT.loaded}).then(function(YT){_this2.container&&(_this2.player=new YT.Player(_this2.container,_objectSpread({width:"100%",height:"100%",videoId:id,playerVars:_objectSpread({autoplay:playing?1:0,mute:muted?1:0,controls:controls?1:0,start:(0,
_utils.parseStartTime)(url),end:(0,_utils.parseEndTime)(url),origin:window.location.origin,playsinline},parsePlaylist(url),{},playerVars),events:{onReady:function(){loop&&_this2.player.setLoop(!0);_this2.props.onReady()},onStateChange:_this2.onStateChange,onError:function(event){return _onError(event.data)}}},embedOptions)))},_onError)}},{key:"play",value:function(){this.callPlayer("playVideo")}},{key:"pause",value:function(){this.callPlayer("pauseVideo")}},{key:"stop",value:function(){document.body.contains(this.callPlayer("getIframe"))&&
this.callPlayer("stopVideo")}},{key:"seekTo",value:function(amount){this.callPlayer("seekTo",amount);this.props.playing||this.pause()}},{key:"setVolume",value:function(fraction){this.callPlayer("setVolume",100*fraction)}},{key:"setPlaybackRate",value:function(rate){this.callPlayer("setPlaybackRate",rate)}},{key:"setLoop",value:function(loop){this.callPlayer("setLoop",loop)}},{key:"getDuration",value:function(){return this.callPlayer("getDuration")}},{key:"getCurrentTime",value:function(){return this.callPlayer("getCurrentTime")}},
{key:"getSecondsLoaded",value:function(){return this.callPlayer("getVideoLoadedFraction")*this.getDuration()}},{key:"render",value:function(){return _react["default"].createElement("div",{style:{width:"100%",height:"100%",display:this.props.display}},_react["default"].createElement("div",{ref:this.ref}))}}]);return YouTube}(_react.Component);exports.YouTube=require;_defineProperty(require,"displayName","YouTube");_defineProperty(require,"canPlay",function(url){return MATCH_URL.test(url)});global=
(0,global["default"])(require);exports["default"]=global}
//# sourceMappingURL=module$node_modules$react_player$lib$players$YouTube.js.map

==> gorilla-notes-0.5.0.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$players$YouTube.js <==
shadow$provide.module$node_modules$react_player$lib$players$YouTube=function(global,require,module,exports){function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===
Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:
{};i%2?ownKeys(Object(source),!0).forEach(function(key){_defineProperty(target,key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=
!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _createSuper(Derived){return function(){var Super=_getPrototypeOf(Derived);if(_isNativeReflectConstruct()){var NewTarget=_getPrototypeOf(this).constructor;Super=Reflect.construct(Super,arguments,
NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _isNativeReflectConstruct(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,
[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,
configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value:value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}function _arrayLikeToArray(arr,len){if(null==len||len>arr.length)len=arr.length;for(var i=0,arr2=Array(len);i<
len;i++)arr2[i]=arr[i];return arr2}function parsePlaylist(url){if(MATCH_PLAYLIST.test(url)){url=url.match(MATCH_PLAYLIST);var JSCompiler_temp=Array.isArray(url)?url:void 0;if(!JSCompiler_temp)if("undefined"!==typeof Symbol&&Symbol.iterator in Object(url)){JSCompiler_temp=[];var _n=!0,_d=!1,_e=void 0;try{var JSCompiler_temp$jscomp$0=url[Symbol.iterator]();for(var _s;!(_n=(_s=JSCompiler_temp$jscomp$0.next()).done)&&(JSCompiler_temp.push(_s.value),2!==JSCompiler_temp.length);_n=!0);}catch(err){_d=!0,
_e=err}finally{try{if(!_n&&null!=JSCompiler_temp$jscomp$0["return"])JSCompiler_temp$jscomp$0["return"]()}finally{if(_d)throw _e;}}}else JSCompiler_temp=void 0;if(!(JSCompiler_temp$jscomp$0=JSCompiler_temp))a:{if(url){if("string"===typeof url){JSCompiler_temp$jscomp$0=_arrayLikeToArray(url,2);break a}JSCompiler_temp$jscomp$0=Object.prototype.toString.call(url).slice(8,-1);"Object"===JSCompiler_temp$jscomp$0&&url.constructor&&(JSCompiler_temp$jscomp$0=url.constructor.name);if("Map"===JSCompiler_temp$jscomp$0||
"Set"===JSCompiler_temp$jscomp$0){JSCompiler_temp$jscomp$0=Array.from(JSCompiler_temp$jscomp$0);break a}if("Arguments"===JSCompiler_temp$jscomp$0||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(JSCompiler_temp$jscomp$0)){JSCompiler_temp$jscomp$0=_arrayLikeToArray(url,2);break a}}JSCompiler_temp$jscomp$0=void 0}if(!(url=JSCompiler_temp$jscomp$0))throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
return{listType:"playlist",list:url[1]}}return{}}Object.defineProperty(exports,"__esModule",{value:!0});exports["default"]=exports.YouTube=void 0;var _react=function(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{"default":obj};var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,
key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,key,desc):newObj[key]=obj[key]}newObj["default"]=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index")),_utils=require("module$node_modules$react_player$lib$utils");global=function(obj){return obj&&obj.__esModule?obj:{"default":obj}}(require("module$node_modules$react_player$lib$singlePlayer"));var MATCH_URL=/(?:youtu\.be\/|youtube\.com\/(?:embed\/|v\/|watch\?v=|watch\?.+&v=))((\w|-){11})|youtube\.com\/playlist\?list=/,
MATCH_PLAYLIST=/list=([a-zA-Z0-9_-]+)/;require=function(_Component){function YouTube(){if(!(this instanceof YouTube))throw new TypeError("Cannot call a class as a function");for(var _len=arguments.length,args=Array(_len),_key=0;_key<_len;_key++)args[_key]=arguments[_key];var _this=_super.call.apply(_super,[this].concat(args));_defineProperty(_assertThisInitialized(_this),"callPlayer",_utils.callPlayer);_defineProperty(_assertThisInitialized(_this),"onStateChange",function(_ref){_ref=_ref.data;var _this$props=
_this.props,onPlay=_this$props.onPlay,onPause=_this$props.onPause,onBuffer=_this$props.onBuffer,onBufferEnd=_this$props.onBufferEnd,onEnded=_this$props.onEnded,onReady=_this$props.onReady;_this$props=_this$props.loop;var _window$SDK_GLOBAL$Pl=window.YT.PlayerState,PAUSED=_window$SDK_GLOBAL$Pl.PAUSED,BUFFERING=_window$SDK_GLOBAL$Pl.BUFFERING,ENDED=_window$SDK_GLOBAL$Pl.ENDED,CUED=_window$SDK_GLOBAL$Pl.CUED;_ref===_window$SDK_GLOBAL$Pl.PLAYING&&(onPlay(),onBufferEnd());_ref===PAUSED&&onPause();_ref===
BUFFERING&&onBuffer();_ref===ENDED&&(onPlay=!!_this.callPlayer("getPlaylist"),_this$props&&!onPlay&&_this.play(),onEnded());_ref===CUED&&onReady()});_defineProperty(_assertThisInitialized(_this),"mute",function(){_this.callPlayer("mute")});_defineProperty(_assertThisInitialized(_this),"unmute",function(){_this.callPlayer("unMute")});_defineProperty(_assertThisInitialized(_this),"ref",function(container){_this.container=container});return _this}_inherits(YouTube,_Component);var _super=_createSuper(YouTube);
_createClass(YouTube,[{key:"load",value:function(url,isReady){var _this2=this,_this$props2=this.props,playing=_this$props2.playing,muted=_this$props2.muted,playsinline=_this$props2.playsinline,controls=_this$props2.controls,loop=_this$props2.loop,_onError=_this$props2.onError;_this$props2=_this$props2.config.youtube;var playerVars=_this$props2.playerVars,embedOptions=_this$props2.embedOptions,id=url&&url.match(MATCH_URL)[1];isReady?MATCH_PLAYLIST.test(url)?this.player.loadPlaylist(parsePlaylist(url)):
this.player.cueVideoById({videoId:id,startSeconds:(0,_utils.parseStartTime)(url)||playerVars.start,endSeconds:(0,_utils.parseEndTime)(url)||playerVars.end}):(0,_utils.getSDK)("https://www.youtube.com/iframe_api","YT","onYouTubeIframeAPIReady",function(YT){return YT.loaded}).then(function(YT){_this2.container&&(_this2.player=new YT.Player(_this2.container,_objectSpread({width:"100%",height:"100%",videoId:id,playerVars:_objectSpread({autoplay:playing?1:0,mute:muted?1:0,controls:controls?1:0,start:(0,
_utils.parseStartTime)(url),end:(0,_utils.parseEndTime)(url),origin:window.location.origin,playsinline:playsinline},parsePlaylist(url),{},playerVars),events:{onReady:function(){loop&&_this2.player.setLoop(!0);_this2.props.onReady()},onStateChange:_this2.onStateChange,onError:function(event){return _onError(event.data)}}},embedOptions)))},_onError)}},{key:"play",value:function(){this.callPlayer("playVideo")}},{key:"pause",value:function(){this.callPlayer("pauseVideo")}},{key:"stop",value:function(){document.body.contains(this.callPlayer("getIframe"))&&
this.callPlayer("stopVideo")}},{key:"seekTo",value:function(amount){this.callPlayer("seekTo",amount);this.props.playing||this.pause()}},{key:"setVolume",value:function(fraction){this.callPlayer("setVolume",100*fraction)}},{key:"setPlaybackRate",value:function(rate){this.callPlayer("setPlaybackRate",rate)}},{key:"setLoop",value:function(loop){this.callPlayer("setLoop",loop)}},{key:"getDuration",value:function(){return this.callPlayer("getDuration")}},{key:"getCurrentTime",value:function(){return this.callPlayer("getCurrentTime")}},
{key:"getSecondsLoaded",value:function(){return this.callPlayer("getVideoLoadedFraction")*this.getDuration()}},{key:"render",value:function(){return _react["default"].createElement("div",{style:{width:"100%",height:"100%",display:this.props.display}},_react["default"].createElement("div",{ref:this.ref}))}}]);return YouTube}(_react.Component);exports.YouTube=require;_defineProperty(require,"displayName","YouTube");_defineProperty(require,"canPlay",function(url){return MATCH_URL.test(url)});global=
(0,global["default"])(require);exports["default"]=global}
//# sourceMappingURL=module$node_modules$react_player$lib$players$YouTube.js.map
